@@ -89,7 +89,7 @@ sub load {
 
 	foreach my $thread ( grep { length($_) } split /\s*\n---\n\s*/s, $text ) {
 		$self->load_thread( $thread );
-	}	
+	}
 
 	return 1;
 }
@@ -131,7 +131,7 @@ sub load_thread {
 	} else {
 		delete $thread->extra->{out_of_date};
 	}
-	
+
 	$meta_data->{summary} = $summary_text;
 
 	foreach my $field ( keys %$meta_data ) {
@@ -175,7 +175,7 @@ sub emit_list {
 }
 
 sub emit_thread {
-	my ( $self, $thread, $list ) = @_;	
+	my ( $self, $thread, $list ) = @_;
 
 	return if $self->skip_summarized and $thread->summary and !$thread->extra->{out_of_date};
 	return if $thread->hidden and !$self->include_hidden;
@@ -206,13 +206,21 @@ sub emit_head {
 	#local $YAML::UseHeader = 0;
 	#require YAML;
 
+	my %extra_fields;
+
+	foreach my $field ( $self->extra_fields ) {
+		if ( defined( my $value = ($thread->can($field) ? $thread->$field : $thread->extra->{$field}) ) ) {
+			$extra_fields{$field} = $value;
+		}
+	}
+
 	my $yaml = YAML::Syck::Dump({
 		list => $list->name,
 		message_id => $thread->message_id,
 		subject => $thread->subject,
 		( $thread->hidden ? ( hidden => $thread->hidden ) : () ),
 		( $thread->extra->{out_of_date} ? ( out_of_date => 1 ) : () ),
-		map { $_ => $thread->can($_) && defined($thread->can($_)) ? $thread->$_ : $thread->extra->{$_} } $self->extra_fields,
+		%extra_fields,
 	});
 	chomp($yaml);
 	return $yaml;
